"simple.bp" <-
function(x, y, ini3=1.0, maxit=300, pres=1e-8)
{
#
# ------------------------------------------------------------------------------
# Karlis and Ntzoufras (2003, 2004)
# EM algorithms for Bivariate Poisson Models
# ------------------------------------------------------------------------------
#
# x       : 1st vector of counts
# y       : 2nd vector of counts
# ini3    : initial value for lambda3
# maxit   : maximum number of iterations 
# pres    : precision of the relative likelihood difference after which EM stops
# ------------------------------------------------------------------------------
# Data length
n<-length(x)
#
#
#
# initial values
s<-rep(0,n)
like<-1:n*0
zero<- ( x==0 )|( y==0 )
#
#
#
# Initial values for lambda

lambda3<- ini3
lambda1<- max( 0.1, mean(x)-lambda3 )
lambda2<- max( 0.1, mean(y)-lambda3 )
#
#
difllike<-1000.0
loglike0<-1000.0
i<-0
loglike<-rep(0,maxit)
while ( (difllike>pres) && (i <= maxit) ) {
	i<-i+1
	#####   E step  ######
	for (j in 1:n) {
		if (zero[j]) {
			s[j]<-0;
			like[j]<- log(dpois(x[j], lambda1)) + log(dpois(y[j], lambda2))-lambda3;
			}
		else {
			lbp1<- pbivpois( x[j]-1, y[j]-1, lambda=c(lambda1,lambda2,lambda3), log=TRUE );
			lbp2<- pbivpois( x[j]  , y[j]  , lambda=c(lambda1,lambda2,lambda3) , log=TRUE );
			
			s[j]<-exp( log(lambda3) + lbp1 - lbp2 );
			like[j]<-lbp2;
		}
	}
	##### end of E step  ######
	x1<-x-s
	x2<-y-s
	loglike[i]<-sum(like)
	difllike<-abs( (loglike0-loglike[i])/loglike0 )
	loglike0<-loglike[i]
	#
	#
	#####   M step  ######
	#
	# 	fit model on lambda3
	lambda1<-mean(x1)
	lambda2<-mean(x2)
	lambda3<-mean(s)
	#####   end of M step  ######
	printpars<-c(i,lambda1, lambda2, lambda3, ,loglike[i] )
	names(printpars)<-c('Iter.', 'lambda1', 'lambda2', 'lambda3','loglike' )
	print( round(printpars ,3 ) )
	print( paste('Relative Difference in Loglike:', difllike) ) 
	}
#
#	calculation of BIC and AIC of Bivariate Poisson model
	noparams<- 3 
	AIC<- -2*loglike[i] + noparams * 2
	BIC<- -2*loglike[i] + noparams * log(2*n)
#	
#		
#	Calculation of BIC, AIC of Poisson saturated model
	x.mean<-x
	x.mean[x==0]<-1e-12
	y.mean<-y
	y.mean[y==0]<-1e-12
	AIC.sat <-  sum( log( dpois( x , x.mean ) ) + log( dpois(y , y.mean) ) )
	BIC.sat <-  -2 * AIC.sat + (2*n)* log(2*n)
	AIC.sat <-  -2 * AIC.sat + (2*n)* 2
#
#		
#	Calculation of BIC, AIC of simple Poisson model
	x.mean<-mean(x)
	y.mean<-mean(y)
	AIC.pois <-  sum(log( dpois( x , x.mean ) ) + log( dpois( y , y.mean ) ))
	BIC.pois <-  -2 * AIC.pois + 2* log(2*n)
	AIC.pois <-  -2 * AIC.pois + 2* 2
	
	AICtotal<-c(AIC.sat, AIC.pois, AIC)
	BICtotal<-c(BIC.sat, BIC.pois, BIC )
	
	names(AICtotal)<- c( 'Saturated', 'DblPois', 'BivPois' )
	names(BICtotal)<- c( 'Saturated', 'DblPois', 'BivPois' )
#
# Calculation of fitted values
	result<-list(lambda=c(lambda1, lambda2, lambda3),loglikelihood=loglike[1:i],
			parameters=noparams, AIC=AICtotal, BIC=BICtotal ,iterations=i )
#
result
#
#
}

